@@ -17,8 +17,9 @@ use Type::Tiny;
 use Types::Standard -types;
 use File::ShareDir qw/dist_dir/;
 use YAML qw/LoadFile/;
+use File::TypeCategories::Git;
 
-our $VERSION = version->new('0.8.1');
+our $VERSION = version->new('0.8.2');
 our %warned_once;
 
 has ignore => (
@@ -26,6 +27,10 @@ has ignore => (
     isa     => ArrayRef[Str],
     default => sub{[qw{ ignore }]},
 );
+has git => (
+    is  => 'rw',
+    isa => Bool,
+);
 has include => (
     is  => 'rw',
     isa => ArrayRef[Str],
@@ -112,6 +117,12 @@ sub BUILD {
         }
     }
 
+    if ($self->git) {
+        my $git_ignore = File::TypeCategories::Git->new();
+        $self->type_suffixes->{git} = $git_ignore->ignores();
+        push @{ $self->type_suffixes->{ignore} }, 'git';
+    }
+
     return;
 }
 
@@ -246,7 +257,7 @@ File::TypeCategories - Determine if files match a specific type
 
 =head1 VERSION
 
-This documentation refers to File::TypeCategories version 0.8.1
+This documentation refers to File::TypeCategories version 0.8.2
 
 =head1 SYNOPSIS
 
